'##################################################################################
'#                   (C) 2006-2019 KoXo Developpement
'#                         QuickAccess.vbs V1.0
'#
' Pin links to the quick access (Windows 10 at least is required)
' Params : /Folders=... / LinksFolder=...
' /Folders --> List of folders (Comma separated)
' Ex : /Folders="P:\,Q:\,P:\Documents"
' /LinksFolder --> Folder containing shortcuts to folders
' Ex : /LinksFolder="P:\Groups"
'##################################################################################
On Error Resume Next
Dim objArgs, I, Param, strNetworkPath, strShortcutPath
Set objArgs=WScript.Arguments
strLinksFolder=""
strFolders=""
If objArgs.Count>0 Then 
    For I=0 To objArgs.Count-1 
        Param=LCase(objArgs.Item(I))
        If (Instr(Param,"/folders=")=1) Then 
            strFolders=GetValue(objArgs.Item(I))
           End If        
        If Instr(Param,"/linksfolder=")>=1 Then 
            strLinksFolder=GetValue(objArgs.Item(I))
           End If        
    Next
   End If
Set objArgs=Nothing
QuickAccess strFolders, strLinksFolder
WScript.Quit
'##################################################################################
Function QuickAccess(strFolders,strLinksFolder)
On Error Resume Next
If GetOSMajorVersion<10 Then 
    Exit Function
   End If 
If (strFolders="") And (strLinksFolder="") Then 
    Set oScriptShell=CreateObject("WScript.Shell")
    oScriptShell.Popup "QuickAccess.vbs : Missing parameters !",5,"Error",16 
    Set oScriptShell=Nothing
    Exit Function
   End If 
ClearQuickAccess
Set arrNetworkDrivesPath=CreateObject("System.Collections.ArrayList")
If strFolders<>"" Then
    arrFolders=Split(strFolders,",")
    For Each strFolder In arrFolders
        If (Len(strFolder)=3) Then 
            strFolder=Left(strFolder,2)
           End If 
        If (GetDriveType(strFolder)=3) Then 
            strNetworkPath=ResolveNetworkDrive(strFolder)
            arrNetworkDrivesPath.Add(LCase(strNetworkPath))
           End If 
        PinToHome(strFolder)
    Next
   End If 
If strLinksFolder<>"" Then 
    Set arrLinks=EnumFilesInFolder(strLinksFolder,"lnk")
    For Each strLink In arrLinks
         strShortcutPath=GetShortcutTargetPath(strLink)
         If arrNetworkDrivesPath.IndexOf(LCase(strShortcutpath),0)=-1 Then 
             PinToHome(strShortcutPath)
            End If 
    Next
   Set arrLinks=Nothing
   End If 
Set arrNetworkDrives=Nothing
End Function
'##################################################################################
' Pin a quick access
Function PinToHome(Path)
 Dim objShell, objFolder, objFolderItem
 PinToHome=0
 Set objShell=CreateObject("Shell.Application")
 Set objFolder=objShell.Namespace(Path) 
 If Not (objFolder Is Nothing) Then
    Set objFolderItem=objFolder.Self
    objFolderItem.InvokeVerb("pintohome")
    PinToHome=1
    End If
 Set objShell=Nothing
 Set objFolder=Nothing
End Function
'##################################################################################
' Clear quick access
Function ClearQuickAccess
 On Error Resume Next
 Dim objShell, objFolder
 Set objShell=CreateObject("Shell.Application")
 Set objFolder=objShell.NameSpace("shell:::{679f85cb-0220-4080-b29b-5540cc05aab6}")
     For Each Item In objFolder.Items
         Item.InvokeVerb("unpinfromhome")
     Next
 Set objShell=Nothing
 Set objFolder=Nothing
End Function
'##################################################################################
' Return the operating system major version as integer
Function GetOSMajorVersion
 On Error Resume Next
 strComputer="."
 Set objWMIService=GetObject("winmgmts:\\" & strComputer & "\root\cimv2")
 Set colItems=objWMIService.ExecQuery("Select * from Win32_OperatingSystem",,48)
 For Each objItem in colItems
     GetOSMajorVersion=Int(Left(objItem.Version,InStr(objItem.Version,".")-1))
 Next
 Set objWMIService=Nothing
 Set colItems=Nothing
End Function
'##################################################################################
' Get Value from ValueName=Value
Function GetValue(Val)
 Dim I, J
 I=InStr(Val,"=")
 J=Len(Val)
 GetValue=Mid(Val,I+1,J-I)
End Function
'##################################################################################
' Get drive type
' Ex : "C:" --> 2
' 0 -> Unknow   1 -> Removable
' 2 -> Fixed    3 -> Network
' 4 -> CD-ROM   5 -> RAM Disk
Function GetDriveType(drvPath)
 On Error Resume Next
 Dim Fso, Drive
 Set Fso=CreateObject("Scripting.FileSystemObject")
 Set Drive=Fso.GetDrive(drvPath)
 GetDriveType=Drive.DriveType
 Set Fso=Nothing
 Set Drice=Nothing
End Function
'##################################################################################
' Resolve a network drive
' Ex : "X:" --> "\\Server\Share"
Function ResolveNetworkDrive(strDrv)
 On Error Resume Next
 Dim objNetwork, objDrives, I
 Set objNetwork=CreateObject("Wscript.Network")
 Set colDrives=objNetwork.EnumNetworkDrives
 ResolveNetworkDrive=""
 If colDrives.Count>0 Then
     For I=0 To colDrives.Count-1 Step 2
         If UCase(colDrives.Item(I))=UCase(strDrv) Then 
            ResolveNetworkDrive=colDrives.Item(I+1)
            Exit For
         End If
     Next
    End If  
 Set objNetwork=Nothing
 Set colDrives=Nothing
End Function
'##################################################################################
' Enum files with extension in folder
Function EnumFilesInFolder(strPath,strFileExt)
 On Error Resume Next
 Dim objFSo,  objFolder, objFile, colFiles
 Set objFSo=CreateObject("Scripting.FileSystemObject")
 Set objFolder=objFSo.GetFolder(strPath)
 Set arrFiles=CreateObject("System.Collections.ArrayList")
 Set colFiles=objFolder.Files
 For Each objFile In colFiles
     If UCase(objFSo.GetExtensionName(objFile.Name))=UCase(strFileExt) Then
         arrFiles.Add(objFile.Path)  
        End If
 Next
 Set EnumFilesInFolder=arrFiles
 Set arrFiles=Nothing
 Set objFolder=Nothing
 Set objFSo=Nothing 
End Function
'##################################################################################
' Get shortcut Target Path
Function GetShortcutTargetPath(strShortcut)
 On Error Resume Next
 Dim objShell, objShortcut
 Set objShell=CreateObject("WScript.Shell")
 Set objShortcut=objShell.CreateShortcut(strShortcut)
 GetShortcutTargetPath=objShortcut.TargetPath
 Set objShell=Nothing
 Set objShortcut=Nothing
End Function
'##################################################################################